@@ -1,4 +1,5 @@
-# $Id: Cart.pm 1355 2006-08-07 01:51:41Z claco $
+# $Id: Cart.pm 1415 2006-09-14 00:54:13Z claco $
+## no critic
 package AxKit::XSP::Handel::Cart;
 use strict;
 use warnings;
@@ -182,7 +183,7 @@ sub new_start {
 
     throw Handel::Exception::Taglib(
         -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-    ) if ($context[$#context] ne 'root');
+    ) if ($context[-1] ne 'root');
 
     push @context, $tag;
 
@@ -235,7 +236,7 @@ sub new_results_start {
 
     throw Handel::Exception::Taglib(
         -text => translate("Tag '[_1]' not valid here", $tag)
-    ) if ($context[$#context] !~ /^(new|add|cart(s?)|item(s?))$/);
+    ) if ($context[-1] !~ /^(new|add|cart(s?)|item(s?))$/);
 
     push @context, $tag;
 
@@ -372,7 +373,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'new') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -387,8 +388,8 @@ sub new_results_shopper_start {
         ## cart:restore
         } elsif ($tag eq 'restore') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] =~ /^(cart(s?))$/);
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] =~ /^(cart(s?))$/);
 
             push @context, $tag;
 
@@ -405,7 +406,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'cart') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -421,7 +422,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'carts') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -436,8 +437,8 @@ sub new_results_shopper_start {
         ## cart:item
         } elsif ($tag eq 'item') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] =~ /^(cart(s?))$/);
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] =~ /^(cart(s?))$/);
 
             push @context, $tag;
 
@@ -452,8 +453,8 @@ sub new_results_shopper_start {
         ## cart:items
         } elsif ($tag eq 'items') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] =~ /^(cart(s?))$/);
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] =~ /^(cart(s?))$/);
 
             push @context, $tag;
 
@@ -469,7 +470,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'clear') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^(cart(s?))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^(cart(s?))$/);
 
            return "\n\$_xsp_handel_cart_cart->clear;\n";
 
@@ -478,7 +479,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'add') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^(new|cart(s?))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^(new|cart(s?))$/);
 
             push @context, $tag;
 
@@ -494,13 +495,13 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'update') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^((cart(s?)|item(s?)))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^((cart(s?)|item(s?)))$/);
 
             push @context, $tag;
 
-            if ($context[$#context-2] =~ /^(cart(s?))$/) {
+            if ($context[-3] =~ /^(cart(s?))$/) {
                 return "\n\$_xsp_handel_cart_cart->autoupdate(0);\n";
-            } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+            } elsif ($context[-3] =~ /^(item(s?))$/) {
                 return "\n\$_xsp_handel_cart_item->autoupdate(0);\n";
             };
 
@@ -510,7 +511,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'save') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context-1] !~ /^(cart(s?))$/);
+            ) if ($context[-2] !~ /^(cart(s?))$/);
 
             return '
                 $_xsp_handel_cart_cart->save;
@@ -521,7 +522,7 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'delete') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^(cart(s?))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^(cart(s?))$/);
 
             push @context, $tag;
 
@@ -535,11 +536,11 @@ sub new_results_shopper_start {
         ## cart property tags
         ## cart:description, id, name, shopper, type, count, subtotal
         } elsif ($tag =~ /^(description|id|name|shopper|type|count|subtotal)$/) {
-            if ($context[$#context] eq 'new' && $tag !~ /^(count|subtotal)$/) {
+            if ($context[-1] eq 'new' && $tag !~ /^(count|subtotal)$/) {
                 return "\n\$_xsp_handel_cart_new_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'add' && $tag =~ /^(id|description)$/) {
+            } elsif ($context[-1] eq 'add' && $tag =~ /^(id|description)$/) {
                 return "\n\$_xsp_handel_cart_add_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] =~ /^(new|cart(s?))$/) {
+            } elsif ($context[-1] eq 'results' && $context[-2] =~ /^(new|cart(s?))$/) {
                 $e->start_expr($tag);
 
                 if ($tag eq 'subtotal' && ($attr{'format'} || $attr{'convert'})) {
@@ -559,25 +560,25 @@ sub new_results_shopper_start {
                 } else {
                     $e->append_to_script("\$_xsp_handel_cart_cart->$tag;\n");
                 };
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'item') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'item') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_cart_item->$tag;\n");
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'items') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'items') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_cart_item->$tag;\n");
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'add') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'add') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_cart_item->$tag;\n");
-            } elsif ($context[$#context] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
                 return "\n\$_xsp_handel_cart_delete_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'update') {
+            } elsif ($context[-1] eq 'update') {
                 throw Handel::Exception::Taglib(
                     -text => translate("Tag '[_1]' not valid here", $tag)
                 ) if ($tag eq 'id');
 
-                if ($context[$#context-2] =~ /^(cart(s?))$/) {
+                if ($context[-3] =~ /^(cart(s?))$/) {
                     return "\n\$_xsp_handel_cart_cart->$tag(''";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return "\n\$_xsp_handel_cart_item->$tag(''";
                 };
             };
@@ -586,12 +587,12 @@ sub new_results_shopper_start {
         ## cart item property tags
         ## cart:sku, price, quantity, total
         } elsif ($tag =~ /^(sku|price|quantity|total)$/) {
-            if ($context[$#context] eq 'add' && $tag ne 'total') {
+            if ($context[-1] eq 'add' && $tag ne 'total') {
                 return "\n\$_xsp_handel_cart_add_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'add') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'add') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_cart_item->$tag;\n");
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] =~ /^item(s?)$/) {
+            } elsif ($context[-1] eq 'results' && $context[-2] =~ /^item(s?)$/) {
                 $e->start_expr($tag);
 
                 if ($tag =~ /^(price|total)$/ && ($attr{'format'} || $attr{'convert'})) {
@@ -611,12 +612,12 @@ sub new_results_shopper_start {
                 } else {
                     $e->append_to_script("\$_xsp_handel_cart_item->$tag;\n");
                 };
-            } elsif ($context[$#context] eq 'delete') {
+            } elsif ($context[-1] eq 'delete') {
                 return "\n\$_xsp_handel_cart_delete_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'update') {
-                if ($context[$#context-2] =~ /^(cart(s?))$/) {
+            } elsif ($context[-1] eq 'update') {
+                if ($context[-3] =~ /^(cart(s?))$/) {
                     return "\n\$_xsp_handel_cart_cart->$tag(''";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return "\n\$_xsp_handel_cart_item->$tag(''";
                 };
             };
@@ -626,15 +627,15 @@ sub new_results_shopper_start {
         } elsif ($tag eq 'filter') {
             my $key = $attr{'name'} || 'id';
 
-            if ($context[$#context] eq 'cart') {
+            if ($context[-1] eq 'cart') {
                 return "\n\$_xsp_handel_cart_load_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'carts') {
+            } elsif ($context[-1] eq 'carts') {
                 return "\n\$_xsp_handel_carts_load_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'item') {
+            } elsif ($context[-1] eq 'item') {
                 return "\n\$_xsp_handel_cart_item_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'items') {
+            } elsif ($context[-1] eq 'items') {
                 return "\n\$_xsp_handel_cart_items_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'restore') {
+            } elsif ($context[-1] eq 'restore') {
                 return "\n\$_xsp_handel_cart_restore_filter{'$key'} = ''";
             };
 
@@ -643,11 +644,11 @@ sub new_results_shopper_start {
         } elsif ($tag =~ /^result(s?)$/) {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] !~ /^(new|add|cart(s?)|item(s?))$/);
+            ) if ($context[-1] !~ /^(new|add|cart(s?)|item(s?))$/);
 
             push @context, $tag;
 
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 return '
                     if (!$_xsp_handel_cart_called_new && scalar keys %_xsp_handel_cart_new_filter) {
                         $_xsp_handel_cart_cart = Handel::Cart->create(\%_xsp_handel_cart_new_filter);
@@ -656,7 +657,7 @@ sub new_results_shopper_start {
                     if ($_xsp_handel_cart_cart) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'cart') {
+            } elsif ($context[-2] eq 'cart') {
                 return '
                     if (!$_xsp_handel_cart_called_load) {
                         $_xsp_handel_cart_cart = (scalar keys %_xsp_handel_cart_load_filter) ?
@@ -667,7 +668,7 @@ sub new_results_shopper_start {
                     if ($_xsp_handel_cart_cart) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'carts') {
+            } elsif ($context[-2] eq 'carts') {
                 return '
                     if (!$_xsp_handel_carts_called_load) {
                         @_xsp_handel_cart_carts = (scalar keys %_xsp_handel_carts_load_filter) ?
@@ -678,7 +679,7 @@ sub new_results_shopper_start {
                     foreach my $_xsp_handel_cart_cart (@_xsp_handel_cart_carts) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 return '
                     if (!$_xsp_handel_cart_called_item) {
                         $_xsp_handel_cart_item = (scalar keys %_xsp_handel_cart_item_filter) ?
@@ -689,7 +690,7 @@ sub new_results_shopper_start {
                     if ($_xsp_handel_cart_item) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 return '
                     if (!$_xsp_handel_cart_called_items) {
                         @_xsp_handel_cart_items = (scalar keys %_xsp_handel_cart_items_filter) ?
@@ -700,7 +701,7 @@ sub new_results_shopper_start {
                     foreach my $_xsp_handel_cart_item (@_xsp_handel_cart_items) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 return '
                     if (!$_xsp_handel_cart_called_add && scalar keys %_xsp_handel_cart_add_filter) {
                         $_xsp_handel_cart_item = $_xsp_handel_cart_cart->add(\%_xsp_handel_cart_add_filter);
@@ -716,11 +717,11 @@ sub new_results_shopper_start {
         } elsif ($tag =~ /^no-result(s?)$/) {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] !~ /^(new|add|cart(s?)|item(s?))$/);
+            ) if ($context[-1] !~ /^(new|add|cart(s?)|item(s?))$/);
 
             push @context, $tag;
 
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 return '
                     if (!$_xsp_handel_cart_called_new && scalar keys %_xsp_handel_cart_new_filter) {
                         $_xsp_handel_cart_cart = Handel::Cart->create(\%_xsp_handel_cart_new_filter);
@@ -728,7 +729,7 @@ sub new_results_shopper_start {
                     };
                     if (!$_xsp_handel_cart_cart) {
                 ';
-            } elsif ($context[$#context-1] eq 'cart') {
+            } elsif ($context[-2] eq 'cart') {
                 return '
                     if (!$_xsp_handel_cart_called_load) {
                         $_xsp_handel_cart_cart = (scalar keys %_xsp_handel_cart_load_filter) ?
@@ -738,7 +739,7 @@ sub new_results_shopper_start {
                     };
                     if (!$_xsp_handel_cart_cart) {
                 ';
-            } elsif ($context[$#context-1] eq 'carts') {
+            } elsif ($context[-2] eq 'carts') {
                 return '
                     if (!$_xsp_handel_carts_called_load) {
                         @_xsp_handel_cart_carts = (scalar keys %_xsp_handel_carts_load_filter) ?
@@ -748,7 +749,7 @@ sub new_results_shopper_start {
                     };
                     if (!scalar @_xsp_handel_cart_carts) {
                 ';
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 return '
                     if (!$_xsp_handel_cart_called_item) {
                         $_xsp_handel_cart_item = (scalar keys %_xsp_handel_cart_item_filter) ?
@@ -758,7 +759,7 @@ sub new_results_shopper_start {
                     };
                     if (!$_xsp_handel_cart_item) {
                 ';
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 return '
                     if (!$_xsp_handel_cart_called_items) {
                         @_xsp_handel_cart_items = (scalar keys %_xsp_handel_cart_items_filter) ?
@@ -768,7 +769,7 @@ sub new_results_shopper_start {
                     };
                     if (!scalar @_xsp_handel_cart_items) {
                 ';
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 return '
                     if (!$_xsp_handel_cart_called_add && scalar keys %_xsp_handel_cart_add_filter) {
                         $_xsp_handel_cart_item = $_xsp_handel_cart_cart->add(\%_xsp_handel_cart_add_filter);
@@ -853,13 +854,13 @@ sub new_results_shopper_start {
 
         ## cart:update
         } elsif ($tag eq 'update') {
-            if ($context[$#context-2] =~ /^(cart(s?))$/) {
+            if ($context[-3] =~ /^(cart(s?))$/) {
                 pop @context;
                 return '
                     $_xsp_handel_cart_cart->update;
                     $_xsp_handel_cart_cart->autoupdate(1);
                 ';
-            } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+            } elsif ($context[-3] =~ /^(item(s?))$/) {
                 pop @context;
                 return '
                     $_xsp_handel_cart_item->update;
@@ -884,18 +885,18 @@ sub new_results_shopper_start {
         ## cart propery tags
         ## cart:description, id, name, shopper, type, count, subtotal
         } elsif ($tag =~ /^(description|id|name|shopper|type|count|subtotal)$/) {
-            if ($context[$#context] eq 'new' && $tag !~ /^(count|subtotal)$/) {
+            if ($context[-1] eq 'new' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'add' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'add' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'results') {
+            } elsif ($context[-1] eq 'results') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'update') {
-                if ($context[$#context-2] =~ /^(cart(s?))$/) {
+            } elsif ($context[-1] eq 'update') {
+                if ($context[-3] =~ /^(cart(s?))$/) {
                     return ");\n";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return ");\n";
                 };
             };
@@ -904,20 +905,20 @@ sub new_results_shopper_start {
         ## cart item property tags
         ## cart:sku, price, quantity
         } elsif ($tag =~ /^(sku|price|quantity|total)$/) {
-            if ($context[$#context] eq 'add' && $tag ne 'total') {
+            if ($context[-1] eq 'add' && $tag ne 'total') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'add') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'add') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'item') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'item') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'items') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'items') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'update') {
-                if ($context[$#context-2] =~ /^(cart(s?))$/) {
+            } elsif ($context[-1] eq 'update') {
+                if ($context[-3] =~ /^(cart(s?))$/) {
                     return ");\n";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return ");\n";
                 };
             };
@@ -925,42 +926,42 @@ sub new_results_shopper_start {
 
         ## cart:filter
         } elsif ($tag eq 'filter') {
-            if ($context[$#context] eq 'cart') {
+            if ($context[-1] eq 'cart') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'carts') {
+            } elsif ($context[-1] eq 'carts') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'item') {
+            } elsif ($context[-1] eq 'item') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'items') {
+            } elsif ($context[-1] eq 'items') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'restore') {
+            } elsif ($context[-1] eq 'restore') {
                 return ";\n";
             };
 
 
         ## cart:results
         } elsif ($tag =~ /^result(s?)$/) {
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'cart') {
+            } elsif ($context[-2] eq 'cart') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'carts') {
+            } elsif ($context[-2] eq 'carts') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 pop @context;
 
                 return "\n};\n";
@@ -970,27 +971,27 @@ sub new_results_shopper_start {
 
         ## cart:no-results
         } elsif ($tag =~ /^no-result(s?)$/) {
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'cart') {
+            } elsif ($context[-2] eq 'cart') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'carts') {
+            } elsif ($context[-2] eq 'carts') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 pop @context;
 
                 return "\n};\n";
